@@ -10,33 +10,44 @@ class Addr:
         self._network_id = network_id
         self._upb_id = upb_id
         self._is_link = is_link
+        self._index = None
 
     @property
     def network_id(self):
+        """Return the network id."""
         return self._network_id
 
     @property
     def upb_id(self):
+        """Return the device id."""
         return self._upb_id
 
     @property
     def is_device(self):
+        """Return the if this is a device."""
         return not self._is_link
 
     @property
     def is_link(self):
+        """Return the if this is a link."""
         return self._is_link
 
     @property
     def index(self):
+        """Return the address in index form."""
         return self._index
 
+    def __str__(self):
+        """Return the address in index form."""
+        return str(self._index)
+
 
 class Element:
     """Element class"""
 
-    def __init__(self, index, pim):
-        self._index = index
+    def __init__(self, addr, pim):
+        self._addr = addr
+        self._index = addr.index
         self._pim = pim
         self._callbacks = []
         self._changeset = {}
@@ -47,6 +58,11 @@ class Element:
         """Get the index, immutable once class created"""
         return self._index
 
+    @property
+    def addr(self):
+        """Get the address."""
+        return self._addr
+
     def add_callback(self, callback):
         """Callbacks when attribute of element changes"""
         self._callbacks.append(callback)
@@ -56,7 +72,7 @@ class Element:
         if callback in self._callbacks:
             self._callbacks.remove(callback)
 
-    def _call_callbacks(self):
+    def call_callbacks(self):
         """Callbacks when attribute of element changes"""
         for callback in self._callbacks:
             callback(self, self._changeset)
@@ -70,7 +86,7 @@ class Element:
             self._changeset[attr] = new_value
 
         if close_the_changeset and self._changeset:
-            self._call_callbacks()
+            self.call_callbacks()
 
     def __str__(self):
         varlist = {
@@ -96,11 +112,17 @@ class Elements:
         self.pim.add_sync_handler(self.sync)
 
     def add_element(self, element):
+        """Add an element to list of elements."""
         self.elements[element.index] = element
 
-    def connection_status_change(self, new_status):
-        for key, element in self.elements.items():
-            element._call_callbacks()
+    def connection_status_change(self, _):
+        """Force a callback when the PIM becomes connected/disconnected."""
+        for _, element in self.elements.items():
+            element.call_callbacks()
+
+    def sync(self):
+        """Should be overridden by derived class."""
+        raise NotImplementedError()
 
     def __iter__(self):
         for element in self.elements:
